searchData={"items":[{"type":"module","doc":"`Antenna` is a mixture of [`Phoenix.PubSub`](https://hexdocs.pm/phoenix_pubsub/Phoenix.PubSub.html)\n  and [`:gen_event`](https://www.erlang.org/doc/apps/stdlib/gen_event.html) functionality\n  with some batteries included.\n\nIt implements back-pressure on top of `GenStage`, is fully conformant with\n  [OTP Design Principles](https://www.erlang.org/doc/system/events). and\n  is distributed out of the box.\n\n`Antenna` supports both asynchronous _and_ synchronous events. While the most preferrable way\n  would be to stay fully async with `Antenna.event/3`, one still might propagate the event\n  synchronously with `Antenna.sync_event/3` and collect all the responses from all the handlers.\n\nOne can have as many isolated `Antenna`s as necessary, distinguished by `Antenna.t:id/0`.\n\nThe workflow looks like shown below.","title":"Antenna","ref":"Antenna.html"},{"type":"module","doc":"```mermaid\nsequenceDiagram\n  Consumer->>+Broadcaster: sync_event(channel, event)\n  Consumer->>+Broadcaster: event(channel, event) \n  Broadcaster-->>+Consumer@Node1: event\n  Broadcaster-->>+Consumer@Node2: event\n  Broadcaster-->>+Consumer@NodeN: event\n  Consumer@Node1-->>-NoOp: mine?\n  Consumer@NodeN-->>-NoOp: mine?\n  Consumer@Node2-->>+Matchers: event\n  Matchers-->>+Handlers: handle_match/2\n  Matchers-->>+Handlers: handle_match/2\n  Handlers->>-Consumer: response(to: sync_event)\n```\n\n[ASCII representation](https://cascii.app/4164d).","title":"Sequence Diagram - Antenna","ref":"Antenna.html#module-sequence-diagram"},{"type":"module","doc":"The consumer of this library is supposed to declare one or more matchers, subscribing to one\n  or more channels, and then call `Antenna.event/2` to propagate the event.\n\n```elixir\nassert {:ok, _pid, \"{:tag_1, a, _} when is_nil(a)\"} =\n  Antenna.match(Antenna, {:tag_1, a, _} when is_nil(a), self(), channels: [:chan_1])\n\nassert :ok = Antenna.event(Antenna, [:chan_1], {:tag_1, nil, 42})\nassert_receive {:antenna_event, :chan_1, {:tag_1, nil, 42}}\n```","title":"Usage Example - Antenna","ref":"Antenna.html#module-usage-example"},{"type":"type","doc":"The identifier of the channel, messages can be sent to, preferrably `atom()`","title":"Antenna.channel/0","ref":"Antenna.html#t:channel/0"},{"type":"type","doc":"The event being sent to the listeners","title":"Antenna.event/0","ref":"Antenna.html#t:event/0"},{"type":"function","doc":"Sends an event to all the associated matchers through channels.\n\nThe special `:*` might be specified as channels, then the event\n  will be sent to all the registered channels.\n\nIf one wants to collect results of all the registered event handlers,\n  they should look at `sync_event/3` instead.","title":"Antenna.event/3","ref":"Antenna.html#event/3"},{"type":"function","doc":"Adds a handler to the matcher process specified by `pid`","title":"Antenna.handle/3","ref":"Antenna.html#handle/3"},{"type":"type","doc":"The actual handler to be associated with an event(s). It might be either a function\n  or a process id, in which case the message of a following shape will be sent to it.\n\n```elixir\n{:antenna_event, channel, event}\n```","title":"Antenna.handler/0","ref":"Antenna.html#t:handler/0"},{"type":"type","doc":"The identifier of the isolated `Antenna`","title":"Antenna.id/0","ref":"Antenna.html#t:id/0"},{"type":"macro","doc":"Declares a matcher for tagged events.","title":"Antenna.match/4","ref":"Antenna.html#match/4"},{"type":"macro","doc":"```elixir\nAntenna.match(Antenna, %{tag: _, success: false}, fn channel, message ->\n  Logger.warning(\"The processing failed for [\" <> \n    inspect(channel) <> \"], result: \" <> inspect(message))\nend, channels: [:rabbit])\n```","title":"Example - Antenna.match/4","ref":"Antenna.html#match/4-example"},{"type":"function","doc":"Returns a map of matches to matchers","title":"Antenna.registered_matchers/1","ref":"Antenna.html#registered_matchers/1"},{"type":"function","doc":"Subscribes a matcher process specified by `pid` to a channel(s)","title":"Antenna.subscribe/3","ref":"Antenna.html#subscribe/3"},{"type":"function","doc":"Sends an event to all the associated matchers through channels and collects results.\n\nThe special `:*` might be specified as channels, then the event\n  will be sent to all the registered channels.\n\nUnlike `event/3`, this call is _synchronous_, which means it would block until\n  all the registered handlers respond; the results would have been collected\n  and returned as a list of no specific order.","title":"Antenna.sync_event/3","ref":"Antenna.html#sync_event/3"},{"type":"function","doc":"Removes a handler from the matcher process specified by `pid`","title":"Antenna.unhandle/3","ref":"Antenna.html#unhandle/3"},{"type":"macro","doc":"Undeclares a matcher for tagged events previously declared with `Antenna.match/4`.\n\nAccepts both an original match _or_ a name returned by `Antenna.match/4`,\n  which is effectively `Macro.to_string(match)`.","title":"Antenna.unmatch/2","ref":"Antenna.html#unmatch/2"},{"type":"macro","doc":"```elixir\nAntenna.unmatch(Antenna, %{tag: _, success: false})\n```","title":"Example - Antenna.unmatch/2","ref":"Antenna.html#unmatch/2-example"},{"type":"function","doc":"Unsubscribes a previously subscribed matcher process specified by `pid` from the channel(s)","title":"Antenna.unsubscribe/3","ref":"Antenna.html#unsubscribe/3"},{"type":"behaviour","doc":"The behaviour defining matchers in the `Antenna` pub-sub model.\n\nWhile the matcher might be a simple function, or a process identifier,\n  using this behaviour would have your testing process simplified.","title":"Antenna.Matcher","ref":"Antenna.Matcher.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Antenna.Matcher.child_spec/1","ref":"Antenna.Matcher.html#child_spec/1"},{"type":"callback","doc":"The funcion to be called back upon match","title":"Antenna.Matcher.handle_match/2","ref":"Antenna.Matcher.html#c:handle_match/2"},{"type":"type","doc":"The module implementing `handle_match/2` callback","title":"Antenna.Matcher.t/0","ref":"Antenna.Matcher.html#t:t/0"},{"type":"extras","doc":"# Antenna\n\n**The tiny framework to simplify work with events, based on `GenStage`**","title":"Antenna","ref":"readme.html"},{"type":"extras","doc":"`Antenna` is a mixture of [`Phoenix.PubSub`](https://hexdocs.pm/phoenix_pubsub/Phoenix.PubSub.html)\nand [`:gen_event`](https://www.erlang.org/doc/apps/stdlib/gen_event.html) functionality\nwith some batteries included.\n\nIt implements back-pressure on top of `GenStage`, is fully conformant with\n[OTP Design Principles](https://www.erlang.org/doc/system/events). and\nis distributed out of the box.\n\n`Antenna` supports both asynchronous _and_ synchronous events. While the most preferrable way\nwould be to stay fully async with `Antenna.event/3`, one still might propagate the event\nsynchronously with `Antenna.sync_event/3` and collect all the responses from all the handlers.\n\nOne can have as many isolated `Antenna`s as necessary, distinguished by `Antenna.t:id/0`.\n\nThe workflow looks like shown below.","title":"Objective - Antenna","ref":"readme.html#objective"},{"type":"extras","doc":"```\n                        ┌───────────────┐                                               \n                        │               │       Antenna.event(AntID, :tag1, %{foo: 42}) \n                        │  Broadcaster  │───────────────────────────────────────────────\n                        │               │                                               \n                        └───────────────┘                                               \n                              ──/──                                                     \n                        ────── /   ─────                                                \n                  ──────      /         ──────                                          \n            ──────           /                ─────                                     \n        ────                /                      ───                                  \n┌────────────────┐  ┌────────────────┐       ┌────────────────┐                         \n│                │  │                │       │                │                         \n│ Consumer@node1 │  │ Consumer@node1 │   …   │ Consumer@nodeN │                         \n│                │  │                │       │                │                         \n└────────────────┘  └────────────────┘       └────────────────┘                         \n        ·                   ·                         ·                                 \n      /   \\               /   \\                     /   \\                               \n    /       \\           /       \\                 /       \\                             \n  ·   mine?   ·       ·   mine?   ·             ·   mine?   ·                           \n    \\       /           \\       /                 \\       /                             \n      \\   /               \\   /                     \\   /                               \n        ·                   ·                         ·                                 \n        │                   │                         │                                 \n        │                   │                         │                                 \n      ─────                 │                       ─────                               \n                            │                                                           \n                            │                                                           \n                     ┌──────────────┐                                                   \n                     │              │             if (match?), do: call_handlers(event) \n                     │   matchers   │───────────────────────────────────────────────────\n                     │              │                                                   \n                     └──────────────┘                                                   \n```\n\n[ASCII representation](https://cascii.app/4164d).","title":"Flow - Antenna","ref":"readme.html#flow"},{"type":"extras","doc":"The consumer of this library is supposed to declare one or more matchers, subscribing to one\nor more channels, and then call `Antenna.event/2` to propagate the event.","title":"Usage Example - Antenna","ref":"readme.html#usage-example"},{"type":"extras","doc":"```elixir\ndef deps do\n  [\n    {:antenna, \"~> 0.2\"}\n  ]\nend\n```","title":"Installation - Antenna","ref":"readme.html#installation"},{"type":"extras","doc":"Sure, it is.\n\n## [Documentation](https://hexdocs.pm/antenna)","title":"Is it of any good? - Antenna","ref":"readme.html#is-it-of-any-good"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}